import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';


const csvUrl = 'https://gist.githubusercontent.com/SOWMYANAGULA/2d1452708020ed357cb6dd7e9249c9ff/raw/9ddef01553460b9f8c8079077d321e89cf5db7c9/states.csv';
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value(d=>d.Deaths)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#FFD700",
      "#018670",
      "#B22222",
      "#8dc63f",
      "#f58026",
      "#4b4b4b",
      "#9acbc2",
      "#00b5cc",
      "#014140",
      "#d9d5d5",
      "#9400D3"
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Deaths));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Deaths));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Deaths/1000))+"K");
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Deaths = +d.Deaths;
    total += d.Deaths
  });
  console.log(data)
	render(data,total);
};
run();